@@ -16,7 +16,7 @@ with qw(Math::Logic::Ternary::Object);
 
 # ----- static data -----
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 our @CARP_NOT = qw(Math::Logic::Ternary);
 
 use constant MAX_SIZE      => 19683;
@@ -369,11 +369,18 @@ sub _w2i2w {
     return ("as_int$sfx", "convert_int$sfx");
 }
 
+# create an object like left side holding least significant trits of right side
 sub _truncate {
     my ($this, $that) = @_;
+    my $size  = $this->Trits;
     my @trits = $that->Rtrits;
-    splice @trits, scalar $this->Trits;
-    return $this->convert_trits(@trits);
+    if ($size < @trits) {
+        splice @trits, $size;
+        while (@trits && $trits[-1]->is_nil) {
+            pop @trits;
+        }
+    }
+    return bless [$size, \@trits], ref $this;
 }
 
 # COMING_UP (emulated with binary arithmetic for now)
@@ -940,7 +947,7 @@ Math::Logic::Ternary::Word - fixed-size ternary information compound
 
 =head1 VERSION
 
-This documentation refers to version 0.003 of Math::Logic::Ternary::Word.
+This documentation refers to version 0.004 of Math::Logic::Ternary::Word.
 
 =head1 SYNOPSIS
 
